from Products.Archetypes.public import *

GeneralInfoSchema = Schema((

    TextField('address',
               index='FieldIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the address of this object",
                                   description_msgid = "desc_address",
                                   label = "Address",
                                   label_msgid = "label_address",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='General info' ),

    TextField('zipCode',
               index='TextIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the zip code of this object",
                                   description_msgid = "desc_zipCode",
                                   label = "Zip code",
                                   label_msgid = "label_zipCode",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='General info' ),

    TextField('city',
               index='TextIndex',
               required = 1,
               vocabulary='_get_city_vocab',
               widget=SelectionWidget(description = "Fill in the city in which this object is located.",
                                      description_msgid = "desc_city",
                                      label = "City",
                                      label_msgid = "label_city",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),

    IntegerField('price',
               index='FieldIndex',
               required = 1,
               widget=IntegerWidget(description = "Fill in the price without dots or comma's.",
                                    description_msgid = "desc_price",
                                    label = "Price",
                                    label_msgid = "label_price",
                                    i18n_domain = "broker",
                                    size = 30),
               schemata='General info' ),

    TextField('kk_von',
               index='TextIndex',
               required = 1,
               vocabulary='_get_kk_von_vocab',
               widget=SelectionWidget(description = "Select the one option.",
                                      description_msgid = "desc_kk_von",
                                      label = "K.k./V.o.n.",
                                      label_msgid = "label_kk_von",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),

    TextField('type',
               index='FieldIndex',
               vocabulary='_get_type_vocab',
               required = 1,
               widget=SelectionWidget(description = "Select the type object",
                                      description_msgid = "desc_type",
                                      label = "Type",
                                      label_msgid = "label_type",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),

    TextField('rooms',
                required = 1,
                index='FieldIndex',
                vocabulary='_get_rooms_vocab',
                widget=SelectionWidget(label="Rooms",
                                       label_msgid = "label_rooms",
                                       description="Select the number of rooms for this object",
                                       description_msgid = "desc_rooms",
                                       i18n_domain = "broker",),
               schemata='General info' ),

    ))

DescriptionSchema = Schema((

    TextField('desc',
               required = 1,
               widget=TextAreaWidget(description = "Enter a short description for this object.",
                                     description_msgid = "desc_desc",
                                     label = "Description",
                                     label_msgid = "label_desc",
                                     i18n_domain = "broker",
                                     rows = 3),
               schemata='Description' ),

    TextField('mainText',
               required = 1,
               default_content_type = 'text/restructured',
               default_output_type = 'text/html',
               allowable_content_types = ('text/html',),
               widget = RichWidget(description = "Enter the main description for this object.",
                                   description_msgid = "desc_mainText",
                                   label = "Body text",
                                   label_msgid = "label_mainText",
                                   i18n_domain = "broker",
                                   rows = 25 ),
               schemata='Description' ),

    TextField('acceptance',
               index='FieldIndex',
               required = 1,
               widget=StringWidget(description = "Enter a brief description for the acceptance.",
                                   description_msgid = "desc_acceptance",
                                   label = "Acceptance",
                                   label_msgid = "label_acceptance",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Description' ),
    ))

CharacteristicsSchema = Schema((

    TextField('area',
               index='FieldIndex',
               required = 0,
               widget=StringWidget(description = "Fill in the area of the object.",
                                   description_msgid = "desc_area",
                                   label = "Area",
                                   label_msgid = "label_area",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    TextField('volume',
               required = 0,
               widget=StringWidget(description = "Fill in the volume of this object.",
                                   description_msgid = "desc_volume",
                                   label = "Volume",
                                   label_msgid = "label_volume",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    TextField('constructYear',
               required = 0,
               widget=StringWidget(description = "Fill in the year of construction of this object.",
                                   description_msgid = "desc_constructYear",
                                   label = "Construct year",
                                   label_msgid = "label_constructYear",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    LinesField('location',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_location_vocab',
                widget=MultiSelectionWidget(label="Location",
                                            label_msgid = "label_location",
                                            description="""Select the location. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_location",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('kindOfBuilding',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfBuilding_vocab',
                widget=SelectionWidget(label="Kind of building",
                                       label_msgid = "label_kindOfBuilding",
                                       description="Select what kind of building this is.",
                                       description_msgid = "desc_kindOfBuilding",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('balcony',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_balcony_vocab',
                widget=SelectionWidget(label="Balcony",
                                       label_msgid = "label_balcony",
                                       description="Select whether this object has a balcony or not.",
                                       description_msgid = "desc_balcony",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('garden',
               required =  0,
               index='FieldIndex',
               vocabulary='_get_garden_vocab',
               widget=SelectionWidget(label="Garden",
                                      label_msgid = "label_garden",
                                      description="Select whether this object has a garden or not.",
                                      description_msgid = "desc_garden",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),

    LinesField('kindOfGarden',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfGarden_vocab',
                widget=MultiSelectionWidget(label="Kind of garden",
                                       label_msgid = "label_kindOfGarden",
                                       description="""Select the kind of garden. You can choose more than one option.
                                                      Multiple options can be selected/deselected by pressing Ctrl while
                                                      left clicking the options.""",
                                       description_msgid = "desc_kindOfGarden",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('storage',
               required = 0,
               index='FieldIndex',
               vocabulary='_get_storage_vocab',
               widget=SelectionWidget(label="Storage",
                                      label_msgid = "label_storage",
                                      description="Select whether this object has a storage.",
                                      description_msgid = "desc_storage",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),

    TextField('garage',
               required = 0,
               index='FieldIndex',
               vocabulary='_get_garage_vocab',
               widget=SelectionWidget(label="Garage",
                                      label_msgid = "label_garage",
                                      description="Select whether this object has a garage or not.",
                                      description_msgid = "desc_garage",
                                      i18n_domain = "broker"),
               schemata='Characteristics' ),

    LinesField('kindOfGarage',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfGarage_vocab',
                widget=MultiSelectionWidget(label="Kind of garage",
                                            label_msgid = "label_kindOfGarage",
                                            description="""Select the type garage for this object. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_kindOfGarage",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    LinesField('heating',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_heating_vocab',
                widget=MultiSelectionWidget(label="Heating",
                                            label_msgid = "label_heating",
                                            description="""Select the heating system for this object. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_heating",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    LinesField('isolation',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_isolation_vocab',
                widget=MultiSelectionWidget(label="Isolation",
                                            label_msgid = "label_isolation",
                                            description="""Select the kinds of isolation used for this object. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_isolation",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('airco',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_airco_vocab',
                widget=SelectionWidget(label="Airconditioning",
                                       label_msgid = "label_airco",
                                       description="Select whether this object has an airconditioning or not.",
                                       description_msgid = "desc_airco",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),
    ))


BusinessCharsSchema = Schema((

    TextField('area',
               index='FieldIndex',
               required = 0,
               widget=StringWidget(description = "Fill in the area of the object.",
                                   description_msgid = "desc_area",
                                   label = "Area",
                                   label_msgid = "label_area",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    TextField('volume',
               required = 0,
               widget=StringWidget(description = "Fill in the volume of this object.",
                                   description_msgid = "desc_volume",
                                   label = "Volume",
                                   label_msgid = "label_volume",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    TextField('constructYear',
               required = 0,
               widget=StringWidget(description = "Fill in the year of construction of this object.",
                                   description_msgid = "desc_constructYear",
                                   label = "Construct year",
                                   label_msgid = "label_constructYear",
                                   i18n_domain = "broker",
                                   size = 30),
               schemata='Characteristics' ),

    LinesField('location',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_location_vocab',
                widget=MultiSelectionWidget(label="Location",
                                            label_msgid = "label_location",
                                            description="""Select the location. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_location",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('kindOfBuilding',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_kindOfBuilding_vocab',
                widget=SelectionWidget(label="Kind of building",
                                       label_msgid = "label_kindOfBuilding",
                                       description="Select what kind of building this is.",
                                       description_msgid = "desc_kindOfBuilding",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),

    TextField('parking',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_parking_vocab',
                widget=SelectionWidget(label="Private car park",
                                       label_msgid = "label_parking",
                                       description="Select here if this object has a private car park.",
                                       description_msgid = "desc_parking",
                                       i18n_domain = "broker"),
                schemata='Characteristics' ),

    LinesField('heating',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_heating_vocab',
                widget=MultiSelectionWidget(label="Heating",
                                            label_msgid = "label_heating",
                                            description="""Select the heating system for this object. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_heating",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    LinesField('isolation',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_isolation_vocab',
                widget=MultiSelectionWidget(label="Isolation",
                                            label_msgid = "label_isolation",
                                            description="""Select the kinds of isolation used for this object. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_isolation",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),

    LinesField('facilities',
                required = 0,
                index='FieldIndex',
                vocabulary='_get_facilities_vocab',
                widget=MultiSelectionWidget(label="Facilities",
                                            label_msgid = "label_facilities",
                                            description="""Select the facilities. You can choose more than 1 option.
                                                           Multiple options can be selected/deselected by pressing Ctrl while
                                                           left clicking the options.""",
                                            description_msgid = "desc_facilities",
                                            i18n_domain = "broker"),
                schemata='Characteristics' ),
))

BusinessGeneralInfoSchema = Schema((

    TextField('address',
               index='FieldIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the address of this object",
                                   description_msgid = "desc_address",
                                   label = "Address",
                                   label_msgid = "label_address",
                                   i18n_domain = "broker",
                                   size = 30
                                  ),
               schemata='General info' ),

    TextField('zipCode',
               index='TextIndex',
               required = 1,
               widget=StringWidget(description = "Fill in the zip code of this object",
                                   description_msgid = "desc_zipCode",
                                   label = "Zip code",
                                   label_msgid = "label_zipCode",
                                   i18n_domain = "broker",
                                   size = 30
                                  ),
               schemata='General info' ),

    TextField('city',
               index='TextIndex',
               required = 1,
               vocabulary='_get_city_vocab',
               widget=SelectionWidget(description = "Fill in the city in which this object is located.",
                                      description_msgid = "desc_city",
                                      label = "City",
                                      label_msgid = "label_city",
                                      i18n_domain = "broker"
                                     ),
              schemata='General info' ),

    IntegerField('price',
               index='FieldIndex',
               required = 1,
               widget=IntegerWidget(description = "Fill in the price without dots or comma's.",
                                    description_msgid = "desc_price",
                                    label = "Price",
                                    label_msgid = "label_price",
                                    i18n_domain = "broker",
                                    size = 30
                                   ),
               schemata='General info' ),

    TextField('vat',
               index='TextIndex',
               required = 1,
               vocabulary='_get_vat_vocab',
               widget=SelectionWidget(description = "Select the VAT for this object.",
                                      description_msgid = "desc_vat",
                                      label = "VAT",
                                      label_msgid = "label_vat",
                                      i18n_domain = "broker",
                                     ),
               schemata='General info' ),

    TextField('type',
               index='FieldIndex',
               vocabulary='_get_type_vocab',
               required = 1,
               widget=SelectionWidget(description = "Select the type for this object",
                                      description_msgid = "desc_type",
                                      label = "Type",
                                      label_msgid = "label_type",
                                      i18n_domain = "broker"
                                     ),
               schemata='General info' ),


    TextField('rent_buy',
                required = 1,
                index='FieldIndex',
                vocabulary='_get_rent_buy_vocab',
                widget=SelectionWidget(label="Rent/Buy",
                                       label_msgid = "label_rent_buy",
                                       description="Select Rent/buy for this object.",
                                       description_msgid = "desc_rent_buy",
                                       i18n_domain = "broker"),
                schemata='General info' ),

))
